@@ -248,14 +248,6 @@ uint64_t StrToIntHex(std::string_view str, uint64_t defval) {
   return num;
 }
 
-uint64_t StrToIntBigEndian(std::string_view str) {
-  if (str.empty()) {
-    return 0;
-  }
-  const size_t size = std::min(str.size(), sizeof(uint64_t));
-  return ReadFixNum(str.data(), size);
-}
-
 double StrToDouble(std::string_view str, double defval) {
   const unsigned char* rp = reinterpret_cast<const unsigned char*>(str.data());
   const unsigned char* ep = rp + str.size();
@@ -319,6 +311,46 @@ double StrToDouble(std::string_view str, double defval) {
   return num * sign;
 }
 
+uint64_t StrToIntBigEndian(std::string_view str) {
+  if (str.empty()) {
+    return 0;
+  }
+  const size_t size = std::min(str.size(), sizeof(uint64_t));
+  return ReadFixNum(str.data(), size);
+}
+
+long double StrToFloatBigEndian(std::string_view str) {
+  if (str.size() >= sizeof(long double)) {
+    long double num = 0;
+    xmemcpybigendian(&num, str.data(), sizeof(num));
+    return num;
+  }
+  if (str.size() >= sizeof(double)) {
+    double num = 0;
+    xmemcpybigendian(&num, str.data(), sizeof(num));
+    return num;
+  }
+  if (str.size() >= sizeof(float)) {
+    float num = 0;
+    xmemcpybigendian(&num, str.data(), sizeof(num));
+    return num;
+  }
+  return DOUBLENAN;
+}
+
+uint64_t StrToIntDelta(std::string_view str, bool zigzag) {
+  uint64_t num = 0;
+  ReadVarNum(str.data(), str.size(), &num);
+  if (zigzag) {
+    if (num & 0x1) {
+      num = static_cast<int64_t>((num - 1) / 2) * -1 - 1;
+    } else {
+      num = num / 2;
+    }
+  }
+  return num;
+}
+
 void VSPrintF(std::string* dest, const char* format, va_list ap) {
   assert(dest != nullptr && format != nullptr);
   while (*format != '\0') {
@@ -472,6 +504,33 @@ std::string IntToStrBigEndian(uint64_t data, size_t size) {
   return str;
 }
 
+std::string FloatToStrBigEndian(long double data, size_t size) {
+  std::string str(size, 0);
+  if (size >= sizeof(long double)) {
+    xmemcpybigendian(const_cast<char*>(str.data()), &data, sizeof(data));
+  } else if (size >= sizeof(double)) {
+    const double num = static_cast<double>(data);
+    xmemcpybigendian(const_cast<char*>(str.data()), &num, sizeof(num));
+  } else if (size >= sizeof(float)) {
+    const float num = static_cast<float>(data);
+    xmemcpybigendian(const_cast<char*>(str.data()), &num, sizeof(num));
+  }
+  return str;
+}
+
+std::string IntToStrDelta(uint64_t data, bool zigzag) {
+  char buf[12];
+  if (zigzag) {
+    if (data > INT64MAX) {
+      data = (data + 1) * -2 + 1;
+    } else {
+      data = data * 2;
+    }
+  }
+  const size_t size = WriteVarNum(buf, data);
+  return std::string(buf, size);
+}
+
 std::vector<std::string> StrSplit(std::string_view str, char delim, bool skip_empty) {
   std::vector<std::string> segments;
   segments.reserve(2);
