@@ -1093,6 +1093,81 @@ inline std::vector<T> DeserializeIntVectorDelta(std::string_view serialized, boo
   return values;
 }
 
+/**
+ * Simplified string_view to convey nullptr and be modifiable.
+ */
+class NullableStringView {
+ public:
+  /**
+   * Constructor for an undefined region.
+   */
+  NullableStringView() : data_(nullptr), size_(0) {}
+
+  /**
+   * Constructor for a C-string.
+   */
+  explicit NullableStringView(const char* str) : data_(str), size_(strlen(str)) {}
+
+  /**
+   * Constructor for a specific region.
+   */
+  NullableStringView(const char* data, size_t size) : data_(data), size_(size) {}
+
+  /**
+   * Constructor for a string object.
+   */
+  explicit NullableStringView(const std::string& str) : data_(str.data()), size_(str.size()) {}
+
+  /**
+   * Constructor for a string view object.
+   */
+  explicit NullableStringView(const std::string_view& str)
+      : data_(str.data()), size_(str.size()) {}
+
+  /**
+   * Gets the pointer to the data region.
+   */
+  const char* data() const {
+    return data_;
+  }
+
+  /**
+   * Gets the size of the region.
+   */
+  size_t size() const {
+    return size_;
+  }
+
+  /**
+   * Gets the string_view object.
+   */
+  std::string_view Get() const {
+    return std::string_view(data_, size_);
+  }
+
+  /**
+   * Sets the data.
+   */
+  void Set(const char* data, size_t size) {
+    data_ = data;
+    size_ = size;
+  }
+
+  /**
+   * Sets the data by a string view.
+   */
+  void Set(std::string_view str) {
+    data_ = str.data();
+    size_ = str.size();
+  }
+
+ private:
+  /** The pointer to the data region. */
+  const char* data_;
+  /** The size of the region. */
+  size_t size_;
+};
+
 /**
  * Wrapper of string_view of allocated memory.
  */
