@@ -1348,6 +1348,38 @@ TEST(StrUtilTest, SerializeIntVectorDelta) {
   EXPECT_THAT(int64res, ElementsAreArray(int64vec));
 }
 
+TEST(StrUtilTest, NullableStringView) {
+  tkrzw::NullableStringView s1;
+  EXPECT_EQ(nullptr, s1.data());
+  EXPECT_EQ(0, s1.size());
+  const char* const cstr = "foobar";
+  tkrzw::NullableStringView s2(cstr);
+  EXPECT_EQ(cstr, s2.data());
+  EXPECT_EQ(std::strlen(cstr), s2.size());
+  tkrzw::NullableStringView s3(cstr, 3);
+  EXPECT_EQ(cstr, s3.data());
+  EXPECT_EQ(3, s3.size());
+  tkrzw::NullableStringView s4(nullptr, 12345);
+  EXPECT_EQ(nullptr, s4.data());
+  EXPECT_EQ(12345, s4.size());
+  const std::string xstr("1234");
+  tkrzw::NullableStringView s5(xstr);
+  EXPECT_STREQ(xstr.data(), s5.data());
+  EXPECT_EQ(xstr.size(), s5.size());
+  tkrzw::NullableStringView s6(std::string_view("abcde"));
+  EXPECT_STREQ("abcde", s6.data());
+  EXPECT_EQ(5, s6.size());
+  std::string_view sv = s6.Get();
+  EXPECT_STREQ(s6.data(), sv.data());
+  EXPECT_EQ(s6.size(), sv.size());
+  s1.Set(cstr, strlen(cstr));
+  EXPECT_EQ(cstr, s1.data());
+  EXPECT_EQ(std::strlen(cstr), s1.size());
+  s1.Set(sv);
+  EXPECT_EQ(sv.data(), s1.data());
+  EXPECT_EQ(sv.size(), s1.size());
+}
+
 TEST(StrUtilTest, ScopedStringView) {
   {
     char* buf = static_cast<char*>(tkrzw::xmalloc(5));
