@@ -67,16 +67,6 @@ int64_t MakeUniversalTime(struct std::tm& cal) {
 }
 
 int32_t GetLocalTimeDifference(bool use_cache) {
-#if defined(_SYS_LINUX_) || defined(_SYS_MACOSX_)
-  static std::atomic_int32_t tz_cache(INT32MIN);
-  int32_t tz_value = use_cache ? tz_cache.load() : INT32MIN;
-  if (tz_value == INT32MIN) {
-    tzset();
-    tz_cache.store(-timezone);
-    tz_value = tz_cache.load();
-  }
-  return tz_value;
-#else
   static std::atomic_int32_t tz_cache(INT32MIN);
   int32_t tz_value = use_cache ? tz_cache.load() : INT32MIN;
   if (tz_value == INT32MIN) {
@@ -89,7 +79,6 @@ int32_t GetLocalTimeDifference(bool use_cache) {
     tz_value = tz_cache.load();
   }
   return tz_value;
-#endif
 }
 
 int32_t GetDayOfWeek(int32_t year, int32_t mon, int32_t day) {
@@ -112,9 +101,9 @@ size_t FormatDateSimple(char* result, int64_t wtime, int32_t td) {
   GetUniversalCalendar(static_cast<time_t>(wtime + td), &uts);
   uts.tm_year += 1900;
   uts.tm_mon += 1;
-  return std::sprintf(result, "%04d/%02d/%02d %02d:%02d:%02d",
-                      uts.tm_year, uts.tm_mon, uts.tm_mday,
-                      uts.tm_hour, uts.tm_min, uts.tm_sec);
+  return std::snprintf(result, 20, "%04d/%02d/%02d %02d:%02d:%02d",
+                       uts.tm_year, uts.tm_mon, uts.tm_mday,
+                       uts.tm_hour, uts.tm_min, uts.tm_sec);
 }
 
 size_t FormatDateSimpleWithFrac(char* result, double wtime, int32_t td, int32_t frac_cols) {
